@@ -92,7 +92,8 @@ mode_ionian <- function(key = "c", collapse = FALSE, ignore_octave = FALSE){
 mode_dorian <- function(key = "c", collapse = FALSE, ignore_octave = FALSE){
   x <- scale_major(key, ignore_octave = ignore_octave)
   idx <- c(3, 7)
-  x[idx] <- sapply(x[idx], transpose, n = -1, key = key, style = "strip")
+  x[idx] <- sapply(x[idx], transpose, n = -1, key = key) %>%
+    .pitch_to_note()
   if(collapse) x <- paste0(x, collapse = " ")
   note_set_key(x, key)
 }
@@ -102,7 +103,8 @@ mode_dorian <- function(key = "c", collapse = FALSE, ignore_octave = FALSE){
 mode_phrygian <- function(key = "c", collapse = FALSE, ignore_octave = FALSE){
   x <- scale_major(key, ignore_octave = ignore_octave)
   idx <- c(2, 3, 6, 7)
-  x[idx] <- sapply(x[idx], transpose, n = -1, key = key, style = "strip")
+  x[idx] <- sapply(x[idx], transpose, n = -1, key = key) %>%
+    .pitch_to_note()
   if(collapse) x <- paste0(x, collapse = " ")
   note_set_key(x, key)
 }
@@ -112,7 +114,8 @@ mode_phrygian <- function(key = "c", collapse = FALSE, ignore_octave = FALSE){
 mode_lydian <- function(key = "c", collapse = FALSE, ignore_octave = FALSE){
   x <- scale_major(key, ignore_octave = ignore_octave)
   idx <- 4
-  x[idx] <- sapply(x[idx], transpose, n = 1, key = key, style = "strip")
+  x[idx] <- sapply(x[idx], transpose, n = 1, key = key) %>%
+    .pitch_to_note()
   if(collapse) x <- paste0(x, collapse = " ")
   note_set_key(x, key)
 }
@@ -122,7 +125,8 @@ mode_lydian <- function(key = "c", collapse = FALSE, ignore_octave = FALSE){
 mode_mixolydian <- function(key = "c", collapse = FALSE, ignore_octave = FALSE){
   x <- scale_major(key, ignore_octave = ignore_octave)
   idx <- 7
-  x[idx] <- sapply(x[idx], transpose, n = -1, key = key, style = "strip")
+  x[idx] <- sapply(x[idx], transpose, n = -1, key = key) %>%
+    .pitch_to_note()
   if(collapse) x <- paste0(x, collapse = " ")
   note_set_key(x, key)
 }
@@ -132,7 +136,8 @@ mode_mixolydian <- function(key = "c", collapse = FALSE, ignore_octave = FALSE){
 mode_aeolian <- function(key = "c", collapse = FALSE, ignore_octave = FALSE){
   x <- scale_major(key, ignore_octave = ignore_octave)
   idx <- c(3, 6, 7)
-  x[idx] <- sapply(x[idx], transpose, n = -1, key = key, style = "strip")
+  x[idx] <- sapply(x[idx], transpose, n = -1, key = key) %>%
+    .pitch_to_note()
   if(collapse) x <- paste0(x, collapse = " ")
   note_set_key(x, key)
 }
@@ -142,7 +147,8 @@ mode_aeolian <- function(key = "c", collapse = FALSE, ignore_octave = FALSE){
 mode_locrian <- function(key = "c", collapse = FALSE, ignore_octave = FALSE){
   x <- scale_major(key, ignore_octave = ignore_octave)
   idx <- c(2, 3, 5, 6, 7)
-  x[idx] <- sapply(x[idx], transpose, n = -1, key = key, style = "strip")
+  x[idx] <- sapply(x[idx], transpose, n = -1, key = key) %>%
+    .pitch_to_note()
   if(collapse) x <- paste0(x, collapse = " ")
   note_set_key(x, key)
 }
